@@ -70,6 +70,8 @@ protected:
         m_roleNames.insert(RoleStage, "stage");
         m_roleNames.insert(RoleState, "state");
         m_roleNames.insert(RoleFocused, "focused");
+        m_roleNames.insert(RoleIsTouchApp, "isTouchApp");
+        m_roleNames.insert(RoleExemptFromLifecycle, "exemptFromLifecycle");
 
         connect(this, SIGNAL(rowsInserted(QModelIndex, int, int)), SIGNAL(countChanged()));
         connect(this, SIGNAL(rowsRemoved(QModelIndex, int, int)), SIGNAL(countChanged()));
@@ -92,6 +94,8 @@ public:
         RoleStage,
         RoleState,
         RoleFocused,
+        RoleIsTouchApp,
+        RoleExemptFromLifecycle,
     };
 
     /// @cond
