@@ -30,9 +30,11 @@ namespace scopes
 {
 
 class CategoriesInterface;
-class PreviewStackInterface;
+class PreviewModelInterface;
 class NavigationInterface;
 class SettingsModelInterface;
+class FiltersInterface;
+class FilterBaseInterface;
 
 /**
  * @brief Object representing scope instance, which exposes model(s) with results.
@@ -73,6 +75,11 @@ class UNITY_API ScopeInterface : public QObject
      */
     Q_PROPERTY(bool searchInProgress READ searchInProgress NOTIFY searchInProgressChanged)
 
+    /**
+     * @brief Boolean specifying whether an activation request is currently running.
+     */
+    Q_PROPERTY(bool activationInProgress READ activationInProgress NOTIFY activationInProgressChanged)
+
     /**
      * @brief Boolean specifying whether the scope is favourited.
      */
@@ -92,6 +99,11 @@ class UNITY_API ScopeInterface : public QObject
      */
     Q_PROPERTY(unity::shell::scopes::SettingsModelInterface* settings READ settings NOTIFY settingsChanged)
 
+    /**
+     * @brief
+     */
+    Q_PROPERTY(unity::shell::scopes::FilterBaseInterface* primaryNavigationFilter READ primaryNavigationFilter NOTIFY primaryNavigationFilterChanged)
+
     /**
      * @brief Current search query.
      *
@@ -128,16 +140,6 @@ class UNITY_API ScopeInterface : public QObject
      */
     Q_PROPERTY(bool hasNavigation READ hasNavigation NOTIFY hasNavigationChanged)
 
-    /**
-     * @brief String specifying currently selected sort order
-     */
-    Q_PROPERTY(QString currentAltNavigationId READ currentAltNavigationId NOTIFY currentAltNavigationIdChanged)
-
-    /**
-     * @brief Boolean specifying whether current query has sort order.
-     */
-    Q_PROPERTY(bool hasAltNavigation READ hasAltNavigation NOTIFY hasAltNavigationChanged)
-
     /**
      * @brief VariantMap with customization properties
      */
@@ -148,6 +150,21 @@ class UNITY_API ScopeInterface : public QObject
      */
     Q_PROPERTY(unity::shell::scopes::ScopeInterface::Status status READ status NOTIFY statusChanged)
 
+    /**
+     * @brief Filters model for the scope.
+     */
+    Q_PROPERTY(unity::shell::scopes::FiltersInterface* filters READ filters NOTIFY filtersChanged)
+
+    /**
+     * @brief Label for the currently active top level navigation (department or primary filter).
+     */
+    Q_PROPERTY(QString primaryNavigationTag READ primaryNavigationTag NOTIFY primaryNavigationTagChanged)
+
+    /**
+     * @brief The number of currently selected filters.
+     */
+    Q_PROPERTY(int activeFiltersCount READ activeFiltersCount NOTIFY activeFiltersCountChanged)
+
 protected:
     /// @cond
     explicit ScopeInterface(QObject* parent = 0) : QObject(parent) { }
@@ -173,19 +190,22 @@ public:
     virtual QString searchHint() const = 0;
     virtual QString shortcut() const = 0;
     virtual bool searchInProgress() const = 0;
+    virtual bool activationInProgress() const = 0;
     virtual bool favorite() const = 0;
     virtual CategoriesInterface* categories() const = 0;
     virtual SettingsModelInterface* settings() const = 0;
+    virtual FilterBaseInterface* primaryNavigationFilter() const = 0;
     virtual QString searchQuery() const = 0;
     virtual QString noResultsHint() const = 0;
     virtual QString formFactor() const = 0;
     virtual bool isActive() const = 0;
     virtual QString currentNavigationId() const = 0;
     virtual bool hasNavigation() const = 0;
-    virtual QString currentAltNavigationId() const = 0;
-    virtual bool hasAltNavigation() const = 0;
     virtual Status status() const = 0;
     virtual QVariantMap customizations() const = 0;
+    virtual FiltersInterface* filters() const = 0;
+    virtual QString primaryNavigationTag() const = 0;
+    virtual int activeFiltersCount() const = 0;
 
     /* setters */
     virtual void setSearchQuery(const QString& search_query) = 0;
@@ -203,10 +223,10 @@ public:
     /**
      * @brief Method used to preview a result.
      *
-     * Returns a new PreviewStackInterface instance. It's caller's responsibility
+     * Returns a new PreviewModelInterface instance. It's caller's responsibility
      * to free it.
      */
-    Q_INVOKABLE virtual unity::shell::scopes::PreviewStackInterface* preview(QVariant const& result, QString const& categoryId) = 0;
+    Q_INVOKABLE virtual unity::shell::scopes::PreviewModelInterface* preview(QVariant const& result, QString const& categoryId) = 0;
 
     /**
      * @brief Cancels the current activation.
@@ -224,14 +244,9 @@ public:
     Q_INVOKABLE virtual unity::shell::scopes::NavigationInterface* getNavigation(QString const& navigationId) = 0;
 
     /**
-     * @brief Get a NavigationInterface instance for the passed altNavigationId.
+     * @brief Request change to the current navigation id.
      */
-    Q_INVOKABLE virtual unity::shell::scopes::NavigationInterface* getAltNavigation(QString const& altNavigationId) = 0;
-
-    /**
-     * @brief Request change to the current navigation or altNavigation id.
-     */
-    Q_INVOKABLE virtual void setNavigationState(QString const& navId, bool altNavigation) = 0;
+    Q_INVOKABLE virtual void setNavigationState(QString const& navId) = 0;
 
     /**
      * @brief Execute canned query.
@@ -243,6 +258,21 @@ public:
      */
     Q_INVOKABLE virtual void refresh() = 0;
 
+    /**
+     * @brief Reset primary navigation filter and its tag in the search bar.
+     */
+    Q_INVOKABLE virtual void resetPrimaryNavigationTag() = 0;
+
+    /**
+     * @brief Reset filters to default values.
+     */
+    Q_INVOKABLE virtual void resetFilters() = 0;
+
+    /*
+     * @brief Method used to activate an action of a result.
+     */
+    Q_INVOKABLE virtual void activateAction(QVariant const& result, QString const& categoryId, QString const& actionId) = 0;
+
 Q_SIGNALS:
     // @cond
     void idChanged();
@@ -251,6 +281,7 @@ Q_SIGNALS:
     void descriptionChanged();
     void searchHintChanged();
     void searchInProgressChanged();
+    void activationInProgressChanged();
     void favoriteChanged();
     void shortcutChanged();
     void categoriesChanged();
@@ -261,11 +292,13 @@ Q_SIGNALS:
     void isActiveChanged();
     void hasNavigationChanged();
     void currentNavigationIdChanged();
-    void hasAltNavigationChanged();
-    void currentAltNavigationIdChanged();
     void customizationsChanged();
     void statusChanged();
     void detailsChanged();
+    void filtersChanged();
+    void primaryNavigationTagChanged();
+    void activeFiltersCountChanged();
+    void primaryNavigationFilterChanged();
     // @endcond
 
     // signals triggered by activate(..) or preview(..) requests.
