@@ -19,6 +19,7 @@
 #include<unity/UnityExceptions.h>
 #include<unity/util/IniParser.h>
 #include<glib.h>
+#include<mutex>
 
 using namespace std;
 
@@ -75,7 +76,7 @@ IniParser::IniParser(const char* filename)
     {
         throw ResourceException("Could not create keyfile parser."); // LCOV_EXCL_LINE
     }
-    if (!g_key_file_load_from_file(kf, filename, G_KEY_FILE_NONE, &e))
+    if (!g_key_file_load_from_file(kf, filename, G_KEY_FILE_KEEP_TRANSLATIONS, &e))
     {
         string message = "Could not load ini file ";
         message += filename;
@@ -128,6 +129,18 @@ std::string IniParser::get_string(const std::string& group, const std::string& k
     return result;
 }
 
+std::string IniParser::get_locale_string(const std::string& group, const std::string& key, const std::string& locale) const
+{
+    gchar* value;
+    GError* e = nullptr;
+    string result;
+    value = g_key_file_get_locale_string(p->k, group.c_str(), key.c_str(), locale.empty() ? nullptr : locale.c_str(), &e);
+    inspect_error(e, "Could not get localized string value", p->filename, group);
+    result = value;
+    g_free(value);
+    return result;
+}
+
 bool IniParser::get_boolean(const std::string& group, const std::string& key) const
 {
     bool rval;
@@ -162,6 +175,25 @@ std::vector<std::string> IniParser::get_string_array(const std::string& group, c
     return result;
 }
 
+std::vector<std::string> IniParser::get_locale_string_array(const std::string& group,
+                                                            const std::string& key,
+                                                            const std::string& locale) const
+{
+    vector<string> result;
+    GError* e = nullptr;
+    gchar** strlist;
+    gsize count;
+    strlist = g_key_file_get_locale_string_list(p->k, group.c_str(), key.c_str(),
+                                                locale.empty() ? nullptr : locale.c_str(), &count, &e);
+    inspect_error(e, "Could not get localized string array", p->filename, group);
+    for (gsize i = 0; i < count; i++)
+    {
+        result.push_back(strlist[i]);
+    }
+    g_strfreev(strlist);
+    return result;
+}
+
 vector<int> IniParser::get_int_array(const std::string& group, const std::string& key) const
 {
     vector<int> result;
