@@ -21,11 +21,11 @@
 
 #include <gtest/gtest.h>
 
-using namespace unity::util;
-
-class MyClass : private NonCopyable
+class MyClass
 {
 public:
+    NONCOPYABLE(MyClass);
+
     UNITY_DEFINES_PTRS(MyClass);
 
     static SPtr create()
