@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 Canonical Ltd.
+ * Copyright 2013,2015 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -24,11 +24,11 @@ using namespace unity::shell::application;
 
 MockApplicationManager::MockApplicationManager(QObject* parent): ApplicationManagerInterface(parent)
 {
-    MockApplicationInfo *item = new MockApplicationInfo("phone-app", "Phone App", "Telephony application", QUrl("/usr/share/pixmaps/some/icon.png"));
+    MockApplicationInfo *item = new MockApplicationInfo("phone-app", "Phone App", "Telephony application", QUrl("/usr/share/pixmaps/some/icon.png"), this);
     m_list.append(item);
-    item = new MockApplicationInfo("camera-app", "Camera App", "Lets you take pictures with the camera.", QUrl("/usr/share/pixmaps/some/icon.png"));
+    item = new MockApplicationInfo("camera-app", "Camera App", "Lets you take pictures with the camera.", QUrl("/usr/share/pixmaps/some/icon.png"), this);
     m_list.append(item);
-    item = new MockApplicationInfo("calendar-app", "Calendar App", "5 missed reminders", QUrl("/usr/share/pixmaps/some/icon.png"));
+    item = new MockApplicationInfo("calendar-app", "Calendar App", "5 missed reminders", QUrl("/usr/share/pixmaps/some/icon.png"), this);
     m_list.append(item);
 }
 
@@ -66,8 +66,10 @@ QVariant MockApplicationManager::data(const QModelIndex& index, int role) const
         return item->state();
     case RoleFocused:
         return item->focused();
-    case RoleScreenshot:
-        return item->screenshot();
+    case RoleIsTouchApp:
+        return item->isTouchApp();
+    case RoleExemptFromLifecycle:
+        return item->exemptFromLifecycle();
     }
 
     return QVariant();
@@ -100,16 +102,6 @@ QString MockApplicationManager::focusedApplicationId() const
     return (first) ? first->appId() : QString();
 }
 
-bool MockApplicationManager::suspended() const
-{
-    return false;
-}
-
-void MockApplicationManager::setSuspended(bool suspended)
-{
-    Q_UNUSED(suspended)
-}
-
 bool MockApplicationManager::requestFocusApplication(const QString &appId)
 {
     Q_UNUSED(appId)
@@ -138,9 +130,3 @@ bool MockApplicationManager::stopApplication(const QString &appId)
     Q_UNUSED(appId)
     return true;
 }
-
-bool MockApplicationManager::updateScreenshot(const QString &appId)
-{
-    Q_UNUSED(appId)
-    return true;
-}
