@@ -88,6 +88,8 @@ QVariant MockLauncherModel::data(const QModelIndex& index, int role) const
         return item->countVisible();
     case RoleFocused:
         return item->focused();
+    case RoleAlerting:
+        return item->alerting();
     }
 
     return QVariant();
@@ -102,6 +104,11 @@ LauncherItemInterface *MockLauncherModel::get(int index) const
     return m_list.at(index);
 }
 
+void MockLauncherModel::setAlerting(const QString &appId, bool alerting) {
+    Q_UNUSED(appId)
+    Q_UNUSED(alerting)
+}
+
 void MockLauncherModel::move(int oldIndex, int newIndex)
 {
     Q_UNUSED(oldIndex)
@@ -141,3 +148,13 @@ void MockLauncherModel::setApplicationManager(unity::shell::application::Applica
 {
     Q_UNUSED(applicationManager)
 }
+
+bool MockLauncherModel::onlyPinned() const
+{
+    return false;
+}
+
+void MockLauncherModel::setOnlyPinned(bool onlyPinned)
+{
+    Q_UNUSED(onlyPinned)
+}
